@@ -470,7 +470,7 @@ class CLI(object):
 		# success exit.
 		success=True,
 		# optional order 1 success message (overwrites success to response.success).
-		response=None,
+		response={},
 		# optional order 2 success message (overwrites success to True).
 		message=None,
 		# optional order 3 message.
@@ -478,7 +478,7 @@ class CLI(object):
 		# json format.
 		json=False,
 	):
-		if response != None:
+		if response != {}:
 			if response["success"] in [True, "True", "true", "TRUE"]:
 				success = True
 				message = response["message"]
@@ -501,7 +501,7 @@ class CLI(object):
 		# success exit.
 		success=True,
 		# optional order 1 success message (overwrites success to response.success).
-		response=None,
+		response={},
 		# optional order 2 success message (overwrites success to True).
 		message=None,
 		# optional order 3 message.
